summaryrefslogtreecommitdiff
path: root/lisp
diff options
context:
space:
mode:
Diffstat (limited to 'lisp')
-rw-r--r--lisp/ChangeLog4
-rw-r--r--lisp/ChangeLog.122
-rw-r--r--lisp/ChangeLog.74
-rw-r--r--lisp/cedet/ChangeLog4
-rw-r--r--lisp/cedet/semantic/bovine/c.el4
-rw-r--r--lisp/dired.el2
-rw-r--r--lisp/gnus/gnus-sum.el2
-rw-r--r--lisp/mh-e/ChangeLog.14
-rw-r--r--lisp/org/ChangeLog5
-rw-r--r--lisp/org/ob-ref.el2
-rw-r--r--lisp/org/ob.el4
-rw-r--r--lisp/org/org-publish.el2
-rw-r--r--lisp/progmodes/cc-vars.el2
-rw-r--r--lisp/textmodes/table.el4
-rw-r--r--lisp/url/ChangeLog2
15 files changed, 30 insertions, 17 deletions
diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index 2bc6b658823..6657a9da7d9 100644
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -1,3 +1,7 @@
+2011-12-06 Juanma Barranquero <lekktu@gmail.com>
+
+ * textmodes/table.el (table-shorten-cell): Fix typo.
+
2011-12-05 Christopher Genovese <genovese.cr@gmail.com> (tiny change)
* emacs-lisp/assoc.el (aput): Fix return value (bug#10146)
diff --git a/lisp/ChangeLog.12 b/lisp/ChangeLog.12
index 2a5a20181e1..b97555f1e9d 100644
--- a/lisp/ChangeLog.12
+++ b/lisp/ChangeLog.12
@@ -6278,7 +6278,7 @@
Register changes using allout-exposure-change-hook.
Disregard aberrant topics.
(allout-shift-in): With universal-argument, make topic a peer of
- it's former offspring. Simplify the code by separating out
+ its former offspring. Simplify the code by separating out
allout-shift-out functionality.
(allout-shift-out): With universal-argument, make offspring peers
of their former container, and its siblings. Implement the
diff --git a/lisp/ChangeLog.7 b/lisp/ChangeLog.7
index 25a80567069..37387121777 100644
--- a/lisp/ChangeLog.7
+++ b/lisp/ChangeLog.7
@@ -12129,7 +12129,7 @@
* cc-mode.el (c-buffer-is-cc-mode):
Definition moved here from cc-vars.el. Also,
- put permanent-local property on variable so it's value won't get
+ put permanent-local property on variable so its value won't get
killed by kill-all-local-variables.
* cc-mode.el (c++-mode, java-mode, objc-mode, idl-mode):
@@ -19534,7 +19534,7 @@
the innermost test. This catches GNU-style comments.
* cc-mode.el (c-add-syntax):
- Move macro definition to before it's first use.
+ Move macro definition to before its first use.
* cc-mode.el (c-submit-bug-report):
Capture buffer local variable values which are
diff --git a/lisp/cedet/ChangeLog b/lisp/cedet/ChangeLog
index f3ff89ddd7f..ccc81e6613e 100644
--- a/lisp/cedet/ChangeLog
+++ b/lisp/cedet/ChangeLog
@@ -1,3 +1,7 @@
+2011-12-06 Juanma Barranquero <lekktu@gmail.com>
+
+ * semantic/bovine/c.el (semantic-tag-abstract-p): Fix typo.
+
2011-11-26 Chong Yidong <cyd@gnu.org>
* semantic/wisent/python-wy.el:
diff --git a/lisp/cedet/semantic/bovine/c.el b/lisp/cedet/semantic/bovine/c.el
index fe659d118e1..4da23498cfc 100644
--- a/lisp/cedet/semantic/bovine/c.el
+++ b/lisp/cedet/semantic/bovine/c.el
@@ -816,7 +816,7 @@ now.
;;
;; will create 2 toplevel tags, one is type A, and the other variable B
;; where the :type of B is just a type tag A that is a prototype, and
- ;; the actual struct info of A is it's own toplevel tag.
+ ;; the actual struct info of A is its own toplevel tag.
(when (or (semantic-tag-of-class-p tag 'function)
(semantic-tag-of-class-p tag 'variable))
(let* ((basetype (semantic-tag-type tag))
@@ -1311,7 +1311,7 @@ Optional PARENT and COLOR as specified with
"Return non-nil if TAG is considered abstract.
PARENT is tag's parent.
In C, a method is abstract if it is `virtual', which is already
-handled. A class is abstract iff it's destructor is virtual."
+handled. A class is abstract iff its destructor is virtual."
(cond
((eq (semantic-tag-class tag) 'type)
(require 'semantic/find)
diff --git a/lisp/dired.el b/lisp/dired.el
index 52bd67751d4..3a82ebcf504 100644
--- a/lisp/dired.el
+++ b/lisp/dired.el
@@ -2678,7 +2678,7 @@ Anything else means ask for each directory."
(defvar dired-re-no-dot "^\\([^.]\\|\\.\\([^.]\\|\\..\\)\\).*")
;; Delete file, possibly delete a directory and all its files.
-;; This function is useful outside of dired. One could change it's name
+;; This function is useful outside of dired. One could change its name
;; to e.g. recursive-delete-file and put it somewhere else.
(defun dired-delete-file (file &optional recursive trash) "\
Delete FILE or directory (possibly recursively if optional RECURSIVE is true.)
diff --git a/lisp/gnus/gnus-sum.el b/lisp/gnus/gnus-sum.el
index 71081063715..10d1b467c37 100644
--- a/lisp/gnus/gnus-sum.el
+++ b/lisp/gnus/gnus-sum.el
@@ -2969,7 +2969,7 @@ When FORCE, rebuild the tool bar."
'gnus-summary-mode-map)))
(when map
;; Need to set `gnus-summary-tool-bar-map' because `gnus-article-mode'
- ;; uses it's value.
+ ;; uses its value.
(setq gnus-summary-tool-bar-map map))))
(set (make-local-variable 'tool-bar-map) gnus-summary-tool-bar-map))
diff --git a/lisp/mh-e/ChangeLog.1 b/lisp/mh-e/ChangeLog.1
index 871b84dd039..65ffb0375ab 100644
--- a/lisp/mh-e/ChangeLog.1
+++ b/lisp/mh-e/ChangeLog.1
@@ -428,7 +428,7 @@
2004-11-08 Satyaki Das <satyaki@theforce.stanford.edu>
* mh-acros.el (mh-funcall-if-exists): In XEmacs, presence of a
- function at compile time doesn't guarantee it's existence at run
+ function at compile time doesn't guarantee its existence at run
time. So make the macro handle that situation better.
2004-11-05 Satyaki Das <satyaki@theforce.stanford.edu>
@@ -10195,7 +10195,7 @@
2002-04-02 Peter S Galbraith <psg@debian.org>
* mh-e.el: 'defvar mh-folder-unseen-seq-name' called a function to
- set it's value, and this happens also on byte-compilation (where
+ set its value, and this happens also on byte-compilation (where
it can fail if the user's MH environment is not setup correctly).
I now set the value of mh-folder-unseen-seq-name at runtime when I
first need it. This should fix Debian bugs
diff --git a/lisp/org/ChangeLog b/lisp/org/ChangeLog
index cb518f97a19..555709f1fa8 100644
--- a/lisp/org/ChangeLog
+++ b/lisp/org/ChangeLog
@@ -1,3 +1,8 @@
+2011-12-06 Juanma Barranquero <lekktu@gmail.com>
+
+ * ob.el (org-babel-expand-body:generic, org-babel-number-p):
+ * ob-ref.el (org-babel-ref-parse): Fix typos.
+
2011-11-24 Juanma Barranquero <lekktu@gmail.com>
* ob.el (org-babel-execute-src-block): Fix typo.
diff --git a/lisp/org/ob-ref.el b/lisp/org/ob-ref.el
index d0a2c14bee9..1e14021a364 100644
--- a/lisp/org/ob-ref.el
+++ b/lisp/org/ob-ref.el
@@ -69,7 +69,7 @@
"Parse a variable ASSIGNMENT in a header argument.
If the right hand side of the assignment has a literal value
return that value, otherwise interpret as a reference to an
-external resource and find it's value using
+external resource and find its value using
`org-babel-ref-resolve'. Return a list with two elements. The
first element of the list will be the name of the variable, and
the second will be an emacs-lisp representation of the value of
diff --git a/lisp/org/ob.el b/lisp/org/ob.el
index f34d1fbda9e..8bba4672169 100644
--- a/lisp/org/ob.el
+++ b/lisp/org/ob.el
@@ -464,7 +464,7 @@ block."
(defun org-babel-expand-body:generic (body params &optional var-lines)
"Expand BODY with PARAMS.
-Expand a block of code with org-babel according to it's header
+Expand a block of code with org-babel according to its header
arguments. This generic implementation of body expansion is
called for languages which have not defined their own specific
org-babel-expand-body:lang function."
@@ -2045,7 +2045,7 @@ appropriate."
cell))
(defun org-babel-number-p (string)
- "If STRING represents a number return it's value."
+ "If STRING represents a number return its value."
(if (and (string-match "^-?[0-9]*\\.?[0-9]*$" string)
(= (length (substring string (match-beginning 0)
(match-end 0)))
diff --git a/lisp/org/org-publish.el b/lisp/org/org-publish.el
index 61edef50738..7a0d7b56e22 100644
--- a/lisp/org/org-publish.el
+++ b/lisp/org/org-publish.el
@@ -715,7 +715,7 @@ If :auto-sitemap is set, publish the sitemap too.
If :makeindex is set, also produce a file theindex.org."
(mapc
(lambda (project)
- ;; Each project uses it's own cache file:
+ ;; Each project uses its own cache file:
(org-publish-initialize-cache (car project))
(let*
((project-plist (cdr project))
diff --git a/lisp/progmodes/cc-vars.el b/lisp/progmodes/cc-vars.el
index 549f94387d2..a4338a3193b 100644
--- a/lisp/progmodes/cc-vars.el
+++ b/lisp/progmodes/cc-vars.el
@@ -586,7 +586,7 @@ in a mode hook, you have to call `c-setup-doc-comment-style'
afterwards to redo that work."
;; Symbols other than those documented above may be used on this
;; variable. If a variable exists that has that name with
- ;; "-font-lock-keywords" appended, it's value is prepended to the
+ ;; "-font-lock-keywords" appended, its value is prepended to the
;; font lock keywords list. If it's a function then it's called and
;; the result is prepended.
:type '(radio
diff --git a/lisp/url/ChangeLog b/lisp/url/ChangeLog
index b4cd24cc6b9..db28770ad0e 100644
--- a/lisp/url/ChangeLog
+++ b/lisp/url/ChangeLog
@@ -2448,7 +2448,7 @@
* lisp/url-nfs.el (url-nfs-create-wrapper): New function to create
wrappers onto the appropriate file-based URLs for file-name-handlers.
- * lisp/url-ftp.el: Moved the FTP stuff into it's own file - it
+ * lisp/url-ftp.el: Moved the FTP stuff into its own file - it
might get messy with file-name-handlers and things.
* lisp/url-http.el (url-http-clean-headers): Fix problem when
diff --git a/lisp/textmodes/table.el b/lisp/textmodes/table.el
index 1a3c5c22815..6f9e592d8ed 100644
--- a/lisp/textmodes/table.el
+++ b/lisp/textmodes/table.el
@@ -345,7 +345,7 @@
;; Above code is well known ~/.emacs idiom for customizing a mode
;; specific keymap however it does not work for this package. This is
;; because there is no table mode in effect. This package does not
;; use a local map therefor you must modify `table-cell-map'
;; explicitly. The correct way of achieving above task is:
;;
;; (add-hook 'table-cell-map-hook
@@ -2155,7 +2155,7 @@ specified."
(defun table-shorten-cell (n)
"Shorten the current cell by N lines by shrinking the cell vertically.
Shortening is done by removing blank lines from the bottom of the cell
-and possibly from the top of the cell as well. Therefor, the cell
+and possibly from the top of the cell as well. Therefore, the cell
must have some bottom/top blank lines to be shorten effectively. This
is applicable to all the cells aligned horizontally with the current
one because they are also shortened in order to keep the rectangular
@@ -345,7 +345,7 @@
;; specific keymap however it does not work for this package. This is
;; because there is no table mode in effect. This package does not
-;; use a local map therefor you must modify `table-cell-map'
+;; use a local map therefore you must modify `table-cell-map'
;; explicitly. The correct way of achieving above task is:
;;